﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/EC2_EXPORTS.h>

namespace Aws {
namespace EC2 {
namespace Model {
enum class DestinationFileFormat { NOT_SET, plain_text, parquet };

namespace DestinationFileFormatMapper {
AWS_EC2_API DestinationFileFormat GetDestinationFileFormatForName(const Aws::String& name);

AWS_EC2_API Aws::String GetNameForDestinationFileFormat(DestinationFileFormat value);
}  // namespace DestinationFileFormatMapper
}  // namespace Model
}  // namespace EC2
}  // namespace Aws
